==> libghemical_2.10.orig.tar.gz: libghemical-2.10/src/libghemicaldefine.h <==
// LIBGHEMICALDEFINE.H : just some macros #defined here...

// Copyright (C) 1998 Tommi Hassinen.

// This program is free software; you can redistribute it and/or modify it
// under the terms of the license (GNU GPL) which comes with this package.

/*################################################################################################*/

#ifndef LIBGHEMICALDEFINE_H
#define LIBGHEMICALDEFINE_H

/*################################################################################################*/

#define WEBSITE "http://www.bioinformatics.org/ghemical"

/*################################################################################################*/

/// NOT_DEFINED is defined as -1; therefore negative values often mean "##not defined".

#define NOT_DEFINED -1

/// The value zero is reserved for unregistered glnames (GUI stuff).

#define GLNAME_UNREGISTERED 0

/*################################################################################################*/

// the platform specific stuff is here...

#ifndef WIN32

#define DIR_SEPARATOR '/'	// directory separator
#define EXT_SEPARATOR '.'	// extension separator
#define AMINO_BUILDER_FILE "builder/amino.txt"
#define NUCLEIC_BUILDER_FILE "builder/nucleic.txt"

#else	// WIN32

#define DIR_SEPARATOR '\\'	// directory separator
#define EXT_SEPARATOR '.'	// extension separator
#define AMINO_BUILDER_FILE "builder\\amino.txt"
#define NUCLEIC_BUILDER_FILE "builder\\nucleic.txt"

#endif	// WIN32

/*################################################################################################*/

#endif	// LIBGHEMICALDEFINE_H

// eof

==> libghemical_2.96.orig.tar.gz: libghemical-2.96/src/libghemicaldefine.h <==
// LIBGHEMICALDEFINE.H : just some macros #defined here...

// Copyright (C) 1998 Tommi Hassinen.

// This program is free software; you can redistribute it and/or modify it
// under the terms of the license (GNU GPL) which comes with this package.

/*################################################################################################*/

#ifndef LIBGHEMICALDEFINE_H
#define LIBGHEMICALDEFINE_H

/*################################################################################################*/

#define WEBSITE "http://www.bioinformatics.org/ghemical"

/*################################################################################################*/

/// NOT_DEFINED is defined as -1; therefore negative values often mean "##not defined".

#define NOT_DEFINED -1

/// The value zero is reserved for unregistered glnames (GUI stuff).

#define GLNAME_UNREGISTERED 0

/*################################################################################################*/

// the platform specific stuff is here...

#ifndef WIN32

#define DIR_SEPARATOR '/'	// directory separator
#define EXT_SEPARATOR '.'	// extension separator

#define NEWLINE "\n"	// a string that does the newline-operation.

#define AMINO_BUILDER_FILE "builder/amino.txt"
#define NUCLEIC_BUILDER_FILE "builder/nucleic.txt"

#else	// WIN32

#define DIR_SEPARATOR '\\'	// directory separator
#define EXT_SEPARATOR '.'	// extension separator

#define NEWLINE "\r\n"	// a string that does the newline-operation.

#define AMINO_BUILDER_FILE "builder\\amino.txt"
#define NUCLEIC_BUILDER_FILE "builder\\nucleic.txt"

#endif	// WIN32

/*################################################################################################*/

#endif	// LIBGHEMICALDEFINE_H

// eof
